tlslite.utils.compat

Package tlslite :: Package utils :: Module compat |
[hide private]
[frames] | no frames]

# Module compat

source code

Miscellaneous functions to mask Python version differences.

Functions | [hide private]
bytesToString(bytes) | source code
createByteArraySequence(seq) | source code
createByteArrayZeros(howMany) | source code
formatExceptionTrace(e) | source code
numBits(n) | source code
stringToBytes(s) | source code

Variables | [hide private]
| __package__ = ``'``tlslite.utils``'``